summaryrefslogtreecommitdiffstats
path: root/lib/Basic/TargetInfo.cpp
diff options
context:
space:
mode:
authorrdivacky <rdivacky@FreeBSD.org>2009-11-04 15:04:32 +0000
committerrdivacky <rdivacky@FreeBSD.org>2009-11-04 15:04:32 +0000
commitb6d5e15aae202f157c6cd63da8fa4b089e7b31e9 (patch)
tree59e0e47a9831dcf0e21e547927c8ebb7e113bfd1 /lib/Basic/TargetInfo.cpp
parent5563df30b9c8d1fe87a54baae0d6bd86642563f4 (diff)
downloadFreeBSD-src-b6d5e15aae202f157c6cd63da8fa4b089e7b31e9.zip
FreeBSD-src-b6d5e15aae202f157c6cd63da8fa4b089e7b31e9.tar.gz
Update clang to r86025.
Diffstat (limited to 'lib/Basic/TargetInfo.cpp')
-rw-r--r--lib/Basic/TargetInfo.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Basic/TargetInfo.cpp b/lib/Basic/TargetInfo.cpp
index 8f3c777..12caf0c 100644
--- a/lib/Basic/TargetInfo.cpp
+++ b/lib/Basic/TargetInfo.cpp
@@ -106,9 +106,9 @@ unsigned TargetInfo::getTypeWidth(IntType T) const {
};
}
/// getTypeSigned - Return whether an integer types is signed. Returns true if
/// the type is signed; false otherwise.
-bool TargetInfo::getTypeSigned(IntType T) const {
+bool TargetInfo::isTypeSigned(IntType T) const {
switch (T) {
default: assert(0 && "not an integer!");
case SignedShort:
@@ -106,9 +106,9 @@ unsigned TargetInfo::getTypeWidth(IntType T) const {
};
}
-/// getTypeSigned - Return whether an integer types is signed. Returns true if
+/// isTypeSigned - Return whether an integer types is signed. Returns true if
/// the type is signed; false otherwise.
OpenPOWER on IntegriCloud